<?php
/*
+-------------------------------------------------------------------------+
|                                                                         |
| @FILE_NAME:   Socket.abstract.php                                       |
| @CLASS_NAME:  (abstract) Jabber                                         |
|                                                                         |
| @DATE:        Wed May,16 2007 07:58:59                                  |
| @LAST_CHANGE: Wed May,16 2007 08:03:28                                  |
|                                                                         |
| @AUTHOR:      [NUTS] Rodrigo Souza - rodsouza@celepar.pr.gov.br         |
|                                                                         |
| @BRIEF:       Abstract class for connect with a socket                  |
|                                                                         |
+-------------------------------------------------------------------------+
*/

abstract class Socket
{
	protected final function open( $pSocket = false, $pTimeOut = 1, $pBlockingMode = 0 )
	{
		if ( !$pSocket )
			return false;

		if ( $socket = @stream_socket_client($pSocket, $errno, $errstr) )
		{
			#stream_set_blocking($socket, $pBlockingMode);
			#stream_set_timeout($socket, $pTimeOut);
			stream_set_blocking($socket, 1);
			stream_set_timeout($socket, 1);
		}
		return $socket;
	}

	protected final function blocking($pSocket = false, $pBlockingMode = 1)
	{
		if ( !$pSocket || !is_resource($pSocket) )
			return false;

		stream_set_blocking($pSocket, $pBlockingMode);
	}


	protected function read( $pSocket = false, $pLength = 4096 )
	{
		ini_set( 'track_errors', '1' );
		$php_errormsg = '';

		if ( !$pSocket || !is_resource($pSocket) )
			return false;

		set_magic_quotes_runtime(0);
		$return = @fread($pSocket, $pLength);
		set_magic_quotes_runtime(get_magic_quotes_gpc());


		if ( $php_errormsg )
			return false;

		return $return;
	}

	protected function write( $pSocket = false, $pData = false )
	{
		ini_set( 'track_errors', '1' );
		$php_errormsg = '';

		if ( (!$pSocket || !is_resource($pSocket)) || !$pData )
			return false;

		$return = @fwrite($pSocket, $pData);

		if ( $php_errormsg )
			return false;

		return $return;
	}

	protected final function close( $pSocket = false )
	{
		if ( !$pSocket || !is_resource($pSocket) )
			return false;

		return fclose($pSocket);
	}
}
?>
